pomdp_py
========

`pomdp_py <https://h2r.github.io/pomdp-py>`_ is a framework to build and solve POMDP problems, written in Python and Cython.

**Why pomdp_py?** It provides a POMDP framework in Python with clean and intuitive interfaces. This makes POMDP-related research or projects accessible to more people. It also helps sharing code and developing a community

Please refer to the `full documentation <https://h2r.github.io/pomdp-py>`_ and `installation instructions <https://h2r.github.io/pomdp-py/html/installation.html>`_.


If you find this library helpful to your work, please cite the `following paper <https://arxiv.org/pdf/2004.10099.pdf>`_::

    @inproceedings{zheng2020pomdp_py,
      title = {pomdp\_py: A Framework to Build and Solve POMDP Problems},
      author = {Zheng, Kaiyu and Tellex, Stefanie},
      booktitle = {ICAPS 2020 Workshop on Planning and Robotics (PlanRob)},
      year = {2020},
      url = {https://icaps20subpages.icaps-conference.org/wp-content/uploads/2020/10/14-PlanRob_2020_paper_3.pdf},
      note = {Arxiv link: "\url{https://arxiv.org/pdf/2004.10099.pdf}"}
   }
